@@ -32,6 +32,12 @@ class Magic(object):
       ffi.close(self.cookie)
     except Exception as exception:
       raise
+  
+  def __enter__(self):
+    return self
+  
+  def __exit__(self, type, value, traceback):
+    del self
 
   @property
   def version(self):
